@@ -1,15 +1,17 @@
-package Acme::CPANAuthors::Canadian;
+package Acme::CPANAuthors::Canadian; # git description: v0.0106-5-gcc89265
+# ABSTRACT: We are Canadian CPAN authors
 
 use warnings;
 use strict;
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0107';
 
 use Acme::CPANAuthors::Register (
     ZOFFIX => 'Zoffix Znet',
     ETHER  => 'Karen Etheridge',
     ROMANF => 'Roman F.',
     GTERMARS    => 'Graham TerMarsch',
+    OALDERS => 'Olaf Alders',
 
     # the following four authors have been submitted by GTERMARS
     STASH   => 'Jeremy Stashewsky',
@@ -19,15 +21,25 @@ use Acme::CPANAuthors::Register (
 );
 
 1;
+
 __END__
 
-=encoding utf8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Acme::CPANAuthors::Canadian - We are Canadian CPAN authors
 
-=head1 SYNOPSIS
+=head1 VERSION
+
+version 0.0107
+
+=head1 DESCRIPTION
+
+This class provides a hash of Canadian CPAN authors' PAUSE ID and name to
+the C<Acme::CPANAuthors> module.
 
     use strict;
     use warnings;
@@ -44,11 +56,6 @@ Acme::CPANAuthors::Canadian - We are Canadian CPAN authors
 
 See documentation for L<Acme::CPANAuthors> for more details.
 
-=head1 DESCRIPTION
-
-This class provides a hash of Canadian CPAN authors' PAUSE ID and name to
-the C<Acme::CPANAuthors> module.
-
 =head1 US PEOPLE
 
 We are Canadian CPAN authors:
@@ -67,52 +74,28 @@ We are Canadian CPAN authors:
 If you are a Canadian CPAN author not listed here, please send me your ID/name
 via email or RT so we can always keep this module up to date.
 
-=head1 AUTHOR
-
-'Zoffix, C<< <'zoffix at cpan.org'> >>
-(L<http://zoffix.com/>, L<http://haslayout.net/>, L<http://zofdesign.com/>)
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-acme-cpanauthors-canadian at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-CPANAuthors-Canadian>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANAuthors-Canadian>
+(or L<bug-Acme-CPANAuthors-Canadian@rt.cpan.org|mailto:bug-Acme-CPANAuthors-Canadian@rt.cpan.org>).
 
-    perldoc Acme::CPANAuthors::Canadian
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
-You can also look for information at:
+=head1 AUTHOR
 
-=over 4
+Zoffix Znet <cpan@zoffix.com>
 
-=item * RT: CPAN's request tracker
+=head1 CONTRIBUTOR
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-CPANAuthors-Canadian>
+=for stopwords Karen Etheridge
 
-=item * AnnoCPAN: Annotated CPAN documentation
+Karen Etheridge <ether@cpan.org>
 
-L<http://annocpan.org/dist/Acme-CPANAuthors-Canadian>
+=head1 COPYRIGHT AND LICENCE
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Acme-CPANAuthors-Canadian>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Acme-CPANAuthors-Canadian>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 'Zoffix, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2008 by Zoffix Znet <cpan@zoffix.com>.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
